---
title: <span class="badge builder"></span> LogGroup
---
# <span class="badge builder"></span> LogGroup

## Constructor

```python
LogGroup()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> cloudwatch.LogGroup
```

### <span class="badge object-method"></span> account_id

AccountId of the log group

```python
def account_id(account_id: str) -> typing.Self
```

### <span class="badge object-method"></span> account_label

Label of the log group

```python
def account_label(account_label: str) -> typing.Self
```

### <span class="badge object-method"></span> arn

ARN of the log group

```python
def arn(arn: str) -> typing.Self
```

### <span class="badge object-method"></span> name

Name of the log group

```python
def name(name: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [LogGroup](./object-LogGroup.md)
